@@ -11,15 +11,16 @@ from ..datum import Datum, print_variables
 from .ureg import build_units_registry
 
 if TYPE_CHECKING:
-    from pint import quantity, UnitRegistry  # lgtm: [py/unused-import]
+    from pint import UnitRegistry, quantity  # lgtm: [py/unused-import]
 
 
 class PhysicalConstantsContext:
-    """CODATA physical constants set from NIST.
+    r"""CODATA physical constants set from NIST.
 
     Parameters
     ----------
-    context : {'CODATA2014', 'CODATA2018'}
+    context : str
+        {'CODATA2014', 'CODATA2018'}
         Origin of loaded data.
 
     Attributes
@@ -28,7 +29,7 @@ class PhysicalConstantsContext:
         The DOI of the current context.
     name : str
         The name of the context ('CODATA2014')
-    pc : dict of Datum
+    pc : Dict[str, Datum]
         Each physical constant is an entry in `pc`, where key is the
         lowercased string of the NIST name (or any alias) and the
         value is a Datum object with `lbl` the exact NIST name string,
@@ -206,7 +207,7 @@ class PhysicalConstantsContext:
 
     @property
     def ureg(self) -> "UnitRegistry":
-        """Returns the internal Pint units registry.
+        r"""Returns the internal Pint units registry.
 
         Returns
         -------
@@ -219,18 +220,18 @@ class PhysicalConstantsContext:
         return self._ureg
 
     def get(self, physical_constant: str, return_tuple: bool = False) -> Union[float, Datum]:
-        """Access a physical constant, `physical_constant`.
+        r"""Access a physical constant, `physical_constant`.
 
         Parameters
         ----------
-        physical_constant : str
+        physical_constant
             Case-insensitive string of physical constant with NIST name.
-        return_tuple : bool, optional
+        return_tuple
             See below.
 
         Returns
         -------
-        Union[float, 'Datum']
+        Union[float, Datum]
             When ``return_tuple=False``, value of physical constant.
             When ``return_tuple=True``, Datum with units, description, uncertainty, and value of physical constant as Decimal.
 
@@ -277,15 +278,15 @@ class PhysicalConstantsContext:
     def conversion_factor(
         self, base_unit: Union[str, "quantity._Quantity"], conv_unit: Union[str, "quantity._Quantity"]
     ) -> float:
-        """Provides the conversion factor from one unit to another.
+        r"""Provides the conversion factor from one unit to another.
 
         The conversion factor is based on the current contexts CODATA.
 
         Parameters
         ----------
-        base_unit : Union[str, 'Quantity']
+        base_unit
             The original units
-        conv_unit : Union[str, 'Quantity']
+        conv_unit
             The units to convert to
 
         Examples
@@ -434,11 +435,11 @@ def run_internal_comparison(old_context: str, new_context: str) -> None:
 
 
 def _get_pi(from_scratch: bool = False) -> "Decimal":
-    """Get pi to 36 digits (or more with mpmath).
+    r"""Get pi to 36 digits (or more with mpmath).
 
     Parameters
     ----------
-    from_scratch : bool, optional
+    from_scratch
         If True, recomputes Pi from mpmath.
 
     Returns
@@ -456,8 +457,8 @@ def _get_pi(from_scratch: bool = False) -> "Decimal":
         return Decimal("3.14159265358979323846264338327950288")
 
 
-def write_c_header(context, filename="physconst.h"):
-    """Write C header file defining physical constants and pi, all with ``pc_`` prefix."""
+def write_c_header(context, filename="physconst.h", prefix="pc_"):
+    """Write C header file defining physical constants and pi, constants names are prefixed."""
 
     self = PhysicalConstantsContext(context)
 
@@ -471,13 +472,13 @@ def write_c_header(context, filename="physconst.h"):
         f"/* This file is autogenerated from the QCElemental python module from {self.name} */",
         "",
         "/* clang-format off */",
-        f"#define pc_pi {pi}",
-        f"#define pc_twopi {tau}",
+        f"#define {prefix}pi {pi}",
+        f"#define {prefix}twopi {tau}",
     ]
 
     for pc, qca in sorted(self.pc.items()):
         callname = qca.label.translate(self._transtable)
-        noncomment = "#define pc_{} {}".format(callname, qca.data)
+        noncomment = "#define {}{} {}".format(prefix, callname, qca.data)
         text.append("{:80}  /*- {} [{}] {} -*/".format(noncomment, qca.label, qca.units, qca.comment))
     text.append("/* clang-format on */")
 
@@ -496,5 +497,39 @@ def write_c_header(context, filename="physconst.h"):
     print("File written ({}). Remember to add license and clang-format it.".format(filename))
 
 
+def write_fortran_header(context, filename="physconst.fh", prefix="pc_", kind=None):
+    """Write Fortran include file defining physical constants and pi, constants names are prefixed.
+    The name of the kind parameter can be passed as well."""
+
+    self = PhysicalConstantsContext(context)
+
+    text = [
+        f"! This file is autogenerated from the QCElemental python module from {self.name}",
+    ]
+
+    pi = _get_pi(from_scratch=False)
+    tau = 2 * pi
+    if kind is None:
+        declare = f"real, parameter ::"
+        text.append(f"{declare} {prefix}pi = {pi}")
+        text.append(f"{declare} {prefix}twopi = {tau}")
+    else:
+        declare = f"real({kind}), parameter ::"
+        text.append(f"{declare} {prefix}pi = {pi}_{kind}")
+        text.append(f"{declare} {prefix}twopi = {tau}_{kind}")
+
+    for pc, qca in sorted(self.pc.items()):
+        callname = qca.label.translate(self._transtable)
+        if kind is None:
+            noncomment = "{} {}{} = {}".format(declare, prefix, callname, qca.data)
+        else:
+            noncomment = "{} {}{} = {}_{}".format(declare, prefix, callname, qca.data, kind)
+        text.append("{:80}  !! {} [{}] {}".format(noncomment, qca.label, qca.units, qca.comment))
+
+    with open(filename, "w") as handle:
+        handle.write("\n".join(text))
+    print("File written ({}). Remember to add license header.".format(filename))
+
+
 # singleton
 constants = PhysicalConstantsContext("CODATA2014")
